<?php

namespace Drupal\az_blob_fs\Asset;

use Drupal\Core\Asset\CssOptimizer;

/**
 * Optimizes a CSS asset.
 */
class AzBlobFsCssOptimizer extends CssOptimizer {

  /**
   * Return absolute urls to access static files which aren't in the Azure blob.
   *
   * @param array $matches
   *   An array of matches by a preg_replace_callback() call that scans for
   *   url() references in CSS files, except for external or absolute ones.
   * @param string|null $base_path
   *   The base path.
   *
   * @return string
   *   The file path.
   */
  public function rewriteFileURI($matches, string $base_path = NULL): string {
    // Prefix with base and remove '../' segments where possible.
    $path = $base_path
      ? $base_path . $matches[1]
      : $this->rewriteFileURIBasePath . $matches[1];

    $last = '';
    while ($path !== $last) {
      $last = $path;
      $path = preg_replace('`(^|/)(?!\.\./)([^/]+)/\.\./`', '$1', $path);
    }

    return 'url(' . file_create_url($path) . ')';
  }

}
