<?php

namespace Drupal\az_blob_fs;

use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\Core\DependencyInjection\ServiceProviderBase;
use Drupal\Core\Site\Settings;
use Symfony\Component\DependencyInjection\Reference;

/**
 * Azure Blob Filesystem Service Provider.
 */
class AzBlobFsServiceProvider extends ServiceProviderBase {

  /**
   * Modifies existing service definitions.
   *
   * @param \Drupal\Core\DependencyInjection\ContainerBuilder $container
   *   The ContainerBuilder whose service definitions can be altered.
   */
  public function alter(ContainerBuilder $container) {
    if (Settings::get('az_blob_fs.use_for_public')) {
      // Fix CSS static urls.
      $container->getDefinition('asset.css.optimizer')
        ->setClass('Drupal\az_blob_fs\Asset\AzBlobFsCssOptimizer')
        ->setArguments([
          new Reference('config.factory'),
        ]);

      if ($container->hasDefinition('file_url_generator')) {
        // @todo Move up to setArguments above when D9.3 is minimally supported version.
        $container->getDefinition('asset.css.optimizer')
          ->addArgument(new Reference('file_url_generator'));
      }
    }
  }

  /**
   * Register dynamic service definitions.
   *
   * @param \Drupal\Core\DependencyInjection\ContainerBuilder $container
   *   The ContainerBuilder whose service definitions can be checked.
   */
  public function register(ContainerBuilder $container) {
    if ($container->hasDefinition('advagg.optimizer.css')) {
    }
  }

}
